pub fn create_computation_with_top_down_worklist_order<'a, T: Context<'a>>(
    problem: T,
    default_value: Option<T::Value>
) -> Computation<GeneralizedContext<'a, T>>
Generate a new computation from the corresponding context and an optional default value for nodes. Uses a top down worklist order when computing the fixpoint.

The worklist order prefers caller nodes before callee nodes.